/**
 *
 * Copyright 2005-2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.util;

import javax.jms.Message;

import java.util.Comparator;

/**
 * A base class for comparators which works on JMS {@link Message} objects
 * 
 * @version $Revision: 2748 $
 */
public abstract class MessageComparatorSupport implements Comparator {

    public int compare(Object object1, Object object2) {
        Message command1 = (Message) object1;
        Message command2 = (Message) object2;
        return compareMessages(command1, command2);
    }

    protected abstract int compareMessages(Message message1, Message message2);

    protected int compareComparators(Comparable comparable, Comparable comparable2) {
        if (comparable != null) {
            return comparable.compareTo(comparable2);
        }
        else if (comparable2 != null) {
            return comparable2.compareTo(comparable) * -1;
        }
        return 0;
    }

}
